@@ -40,7 +40,7 @@ plot.bestNormalize <- function(x, inverse = FALSE, bounds = NULL,
   }
   
   if(is.null(bounds)) {
-    xx <- seq(min(xvals, na.rm = T), max(xvals, na.rm = T), length = 1000)
+    xx <- seq(min(xvals, na.rm = TRUE), max(xvals, na.rm = TRUE), length = 1000)
   } else 
     xx <- seq(min(bounds), max(bounds), length = 1000)
   
@@ -50,7 +50,7 @@ plot.bestNormalize <- function(x, inverse = FALSE, bounds = NULL,
   if(is.null(methods)) {
     methods <- c(names(x$other_transforms))
     ys <- lapply(x$other_transforms, function(obj) {
-      predict(obj, newdata = xx, inverse = inverse, warn = F)
+      predict(obj, newdata = xx, inverse = inverse, warn = FALSE)
     })
   } else {
     methods_found <- intersect(names(x$other_transforms), methods)
@@ -61,7 +61,7 @@ plot.bestNormalize <- function(x, inverse = FALSE, bounds = NULL,
     other_transforms <- x$other_transforms[names(x$other_transforms) %in% methods]
     
     ys <- lapply(other_transforms, function(obj) {
-      predict(obj, newdata = xx, inverse = inverse, warn = F)
+      predict(obj, newdata = xx, inverse = inverse, warn = FALSE)
     })
   }
   
@@ -84,7 +84,7 @@ plot.bestNormalize <- function(x, inverse = FALSE, bounds = NULL,
   
   legend(leg_loc, labs, col = cols, bty = 'n', lwd = 2)
   if(!inverse) 
-    points(x = jitter(xvals), y = rep(min(range(ys, yy, na.rm = T)), length(xvals)), pch = '|')
+    points(x = jitter(xvals), y = rep(min(range(ys, yy, na.rm = TRUE)), length(xvals)), pch = '|')
   else 
     points(x =  rep(min(xvals, bounds), length(x$x)), y = x$x, pch = '_')
   invisible(x)
@@ -104,9 +104,9 @@ plot.orderNorm <- function(x, inverse = FALSE, bounds = NULL, ...) {
   }
     
   if(is.null(bounds)) {
-    xx <- seq(min(xvals, na.rm = T), max(xvals, na.rm = T), length = 1000)
+    xx <- seq(min(xvals, na.rm = TRUE), max(xvals, na.rm = TRUE), length = 1000)
   } else 
-    xx <- seq(min(bounds, na.rm = T), max(bounds, na.rm = T), length = 100)
+    xx <- seq(min(bounds, na.rm = TRUE), max(bounds, na.rm = TRUE), length = 100)
     
   yy <- predict(x, newdata = xx, inverse = inverse, warn = FALSE)
   plot(xvals, x_t, pch = 20, ylim = range(yy, na.rm = TRUE), xlim = range(xx), ...)
